<?php

namespace Laracart\Return\Http\Controllers\Api;

use App\Http\Controllers\Api\AdminController as BaseController;
use Laracart\Return\Http\Requests\ReturnRequest;
use Laracart\Return\Interfaces\ReturnRepositoryInterface;
use Laracart\Return\Models\Return;

/**
 * Admin API controller class.
 */
class ReturnAdminController extends BaseController
{
    /**
     * Initialize return controller.
     *
     * @param type ReturnRepositoryInterface $return
     *
     * @return type
     */
    public function __construct(ReturnRepositoryInterface $return)
    {
        $this->repository = $return;
        parent::__construct();
    }

    /**
     * Display a list of return.
     *
     * @return json
     */
    public function index(ReturnRequest $request)
    {
        $returns  = $this->repository
            ->setPresenter('\\Laracart\\Return\\Repositories\\Presenter\\ReturnListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $returns['code'] = 2000;
        return response()->json($returns) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display return.
     *
     * @param Request $request
     * @param Model   Return
     *
     * @return Json
     */
    public function show(ReturnRequest $request, Return $return)
    {
        $return         = $return->presenter();
        $return['code'] = 2001;
        return response()->json($return)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new return.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(ReturnRequest $request, Return $return)
    {
        $return         = $return->presenter();
        $return['code'] = 2002;
        return response()->json($return)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new return.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(ReturnRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $return          = $this->repository->create($attributes);
            $return          = $return->presenter();
            $return['code']  = 2004;

            return response()->json($return)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }
    }

    /**
     * Show return for editing.
     *
     * @param Request $request
     * @param Model   $return
     *
     * @return json
     */
    public function edit(ReturnRequest $request, Return $return)
    {
        $return         = $return->presenter();
        $return['code'] = 2003;
        return response()-> json($return)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the return.
     *
     * @param Request $request
     * @param Model   $return
     *
     * @return json
     */
    public function update(ReturnRequest $request, Return $return)
    {
        try {

            $attributes = $request->all();

            $return->update($attributes);
            $return         = $return->presenter();
            $return['code'] = 2005;

            return response()->json($return)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the return.
     *
     * @param Request $request
     * @param Model   $return
     *
     * @return json
     */
    public function destroy(ReturnRequest $request, Return $return)
    {
        try {
            $t = $return->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('return::return.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
