<?php

namespace Laracart\Return\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Laracart\Return\Interfaces\ReturnRepositoryInterface;
use Laracart\Return\Repositories\Presenter\ReturnItemTransformer;

/**
 * Pubic API controller class.
 */
class ReturnPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Laracart\Return\Interfaces\ReturnRepositoryInterface $return
     *
     * @return type
     */
    public function __construct(ReturnRepositoryInterface $return)
    {
        $this->repository = $return;
        parent::__construct();
    }

    /**
     * Show return's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $returns = $this->repository
            ->setPresenter('\\Laracart\\Return\\Repositories\\Presenter\\ReturnListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $returns['code'] = 2000;
        return response()->json($returns)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show return.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $return = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($return)) {
            $return         = $this->itemPresenter($module, new ReturnItemTransformer);
            $return['code'] = 2001;
            return response()->json($return)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
