<?php

namespace Laracart\Return\Policies;

use App\User;
use Laracart\Return\Models\Return;

class ReturnPolicy
{

    /**
     * Determine if the given user can view the return.
     *
     * @param User $user
     * @param Return $return
     *
     * @return bool
     */
    public function view(User $user, Return $return)
    {
        if ($user->canDo('return.return.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $return->user_id;
    }

    /**
     * Determine if the given user can create a return.
     *
     * @param User $user
     * @param Return $return
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('return.return.create');
    }

    /**
     * Determine if the given user can update the given return.
     *
     * @param User $user
     * @param Return $return
     *
     * @return bool
     */
    public function update(User $user, Return $return)
    {
        if ($user->canDo('return.return.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $return->user_id;
    }

    /**
     * Determine if the given user can delete the given return.
     *
     * @param User $user
     * @param Return $return
     *
     * @return bool
     */
    public function destroy(User $user, Return $return)
    {
        if ($user->canDo('return.return.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $return->user_id;
    }

    /**
     * Determine if the given user can verify the given return.
     *
     * @param User $user
     * @param Return $return
     *
     * @return bool
     */
    public function verify(User $user, Return $return)
    {
        if ($user->canDo('return.return.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('return.return.verify') 
        && $user->is('manager')
        && $return->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given return.
     *
     * @param User $user
     * @param Return $return
     *
     * @return bool
     */
    public function approve(User $user, Return $return)
    {
        if ($user->canDo('return.return.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
