<?php

namespace Laracart\Return\Providers;

use Illuminate\Support\ServiceProvider;

class ReturnServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'return');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'return');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('return', function ($app) {
            return $this->app->make('Laracart\Return\Return');
        });

// Bind Return to repository
        $this->app->bind(
            \Laracart\Return\Interfaces\ReturnRepositoryInterface::class,
            \Laracart\Return\Repositories\Eloquent\ReturnRepository::class
        );
        // Bind ReturnReason to repository
        $this->app->bind(
            \Laracart\Return\Interfaces\ReturnReasonRepositoryInterface::class,
            \Laracart\Return\Repositories\Eloquent\ReturnReasonRepository::class
        );

        $this->app->register(\Laracart\Return\Providers\AuthServiceProvider::class);
        $this->app->register(\Laracart\Return\Providers\EventServiceProvider::class);
        $this->app->register(\Laracart\Return\Providers\RouteServiceProvider::class);
        // $this->app->register(\Laracart\Return\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['return'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('laracart/return.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/return')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/return')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
