<?php

namespace Laracart\Return\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Laracart\Return\Models\Return;

class ReturnAction
{
    /**
     * Perform the complete action.
     *
     * @param Return $return
     *
     * @return Return
     */
    public function complete(Return $return)
    {
        try {
            $return->status = 'complete';
            return $return->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Return $return
     *
     * @return Return
     */public function verify(Return $return)
    {
        try {
            $return->status = 'verify';
            return $return->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Return $return
     *
     * @return Return
     */public function approve(Return $return)
    {
        try {
            $return->status = 'approve';
            return $return->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Return $return
     *
     * @return Return
     */public function publish(Return $return)
    {
        try {
            $return->status = 'publish';
            return $return->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Return $return
     *
     * @return Return
     */
    public function archive(Return $return)
    {
        try {
            $return->status = 'archive';
            return $return->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Return $return
     *
     * @return Return
     */
    public function unpublish(Return $return)
    {
        try {
            $return->status = 'unpublish';
            return $return->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
