<?php

namespace Laracart\Return\Workflow;

use Laracart\Return\Models\Return;
use Validator;

class ReturnValidator
{

    /**
     * Determine if the given return is valid for complete status.
     *
     * @param Return $return
     *
     * @return bool / Validator
     */
    public function complete(Return $return)
    {
        return Validator::make($return->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given return is valid for verify status.
     *
     * @param Return $return
     *
     * @return bool / Validator
     */
    public function verify(Return $return)
    {
        return Validator::make($return->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given return is valid for approve status.
     *
     * @param Return $return
     *
     * @return bool / Validator
     */
    public function approve(Return $return)
    {
        return Validator::make($return->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given return is valid for publish status.
     *
     * @param Return $return
     *
     * @return bool / Validator
     */
    public function publish(Return $return)
    {
        return Validator::make($return->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given return is valid for archive status.
     *
     * @param Return $return
     *
     * @return bool / Validator
     */
    public function archive(Return $return)
    {
        return Validator::make($return->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given return is valid for unpublish status.
     *
     * @param Return $return
     *
     * @return bool / Validator
     */
    public function unpublish(Return $return)
    {
        return Validator::make($return->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
